import numpy as np


def psth(spikes, **kwargs):

    # expects "spikes" to be a dataframe with spike times as the index, and gids as data
    trange = [kwargs['t_start'], kwargs['t_end']]
    dt = kwargs.get("dt", None)
    duration = trange[1] - trange[0]
    if dt is None:
        dt = 30.0 * float(duration) / len(spikes)
        dt = min(dt, 50.0)  # keep dt<=50.0 ms
        n_bins = int(round(duration / dt))
    else:
        n_bins = int(round(duration / dt))
    counts, bins = np.histogram(spikes.index, bins=n_bins, range=trange)
    db = bins[1] - bins[0]
    c = counts.astype(float) / len(np.unique(spikes)) / db * 1000.0  # factor of 1000 since Hz is in seconds, but time is specified in ms
    c_raw = counts.astype(float) / db * 1000.0

    return dt, c, c_raw, db, bins

